@@ -1,6 +1,6 @@
 package CGI::ContactForm;
 
-$VERSION = '1.52';
+$VERSION = '1.53';
 # $Id: ContactForm.pm,v 1.76 2009/03/03 22:46:53 gunnarh Exp $
 
 =head1 NAME
@@ -240,7 +240,6 @@ L<Mail::Sender|Mail::Sender>
 =cut
 
 use strict;
-use CGI 'escapeHTML';
 use File::Basename;
 use File::Spec;
 use Fcntl qw(:DEFAULT :flock);
@@ -263,6 +262,8 @@ BEGIN {
         exit 1;
     }
 
+    eval "use CGI 'escapeHTML'";
+    CFdie($@) if $@;
     eval "use Mail::Sender";
     CFdie($@) if $@;
 }
